#!/usr/bin/env python
# -*- coding: utf-8 -*-

from game import Game
#import game
from options import Options
import pygtk
pygtk.require('2.0')
import gtk

NORMAL = 0
PRACTICE = 1

class Mainmenu:

    def destroy(self, widget, data=None):
        gtk.main_quit()

    def delete_event(self, widget, event, data=None):
        return False

    def new_game(self, widget, event):
        #print dir(self.win)
        self.win.set_title("Europe")
        self.win.remove(self.box)
        #self.options = Options()
        game = Game("europe", "English", NORMAL)
        game.show()
        self.win.add(game)
        #game.add_events(self.win, 256)
        game.add_events(256)
        self.win.connect("button-press-event", game.mus)
        self.win.connect("key-press-event", game.key)
        self.win.show()
        
        #self.win = None
        #self.win = gtk.Window(gtk.WINDOW_TOPLEVEL)
    
    def options(self, widget, event):
        self.win.remove(self.box)
        options = Options(self)
        options.show()
        self.win.add(options.table)

        #self.options.backbutt.connect("clicked", self.back_to_main)
        self.win.show()


    def do_main(self):
        #self.win.remove(self.options.table)
        self.win.add(self.box)
        self.box.pack_start(self.butt_newgame,True,True,0)
        self.butt_newgame.show()
        self.box.pack_start(self.butt_options,True,True,0)
        self.butt_options.show()
        self.box.pack_start(self.butt_quit,True,True,0)
        self.butt_quit.show()
        

    def quit(self, widget, event):
        gtk.main_quit()

    def __init__(self):
        self.win = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.box = gtk.VBox(True, 1)
        self.butt_newgame = gtk.Button("New Game")
        self.butt_options = gtk.Button("Options")
        self.butt_quit = gtk.Button("Quit")

        self.do_main()

        #self.win.add(self.box)
        #self.box.pack_start(self.butt_newgame,True,True,0)
        #self.butt_newgame.show()
        #self.box.pack_start(self.butt_options,True,True,0)
        #self.butt_options.show()
        #self.box.pack_start(self.butt_quit,True,True,0)
        #self.butt_quit.show()


        self.win.connect("delete_event", self.delete_event)
        self.butt_newgame.connect("clicked", self.new_game, None)
        self.butt_options.connect("clicked", self.options, None)
        self.butt_quit.connect("clicked", self.quit, None)

        self.box.show()
        self.win.show()
        #gtk.main()

    def main(self):
        gtk.main()

if __name__ == "__main__":
    mainmenu = Mainmenu()
    mainmenu.main()
